# ts-ids-core

`ts-ids-core` provides a programmatic way of defining TetraScience Intermediate Data Schema (IDS).
An IDS defined using the `ts-ids-core` framework can be exported to IDS JSON (`jsonschema` v7) and is thus compatible with the Tetra Data Platform (TDP).

To view documentation and release notes, run `ts-ids docs` in the environment where `ts-ids-core` is installed, or visit the [public documentation site](https://ids.tetrascience.com/).

## Version

v2.0.0
